# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['VolumeArgs', 'Volume']

@pulumi.input_type
class VolumeArgs:
    def __init__(__self__, *,
                 region_name: pulumi.Input[builtins.str],
                 service_name: pulumi.Input[builtins.str],
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 image_id: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 size: Optional[pulumi.Input[builtins.float]] = None,
                 snapshot_id: Optional[pulumi.Input[builtins.str]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 volume_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a Volume resource.
        :param pulumi.Input[builtins.str] region_name: Region name
        :param pulumi.Input[builtins.str] service_name: Service name
        :param pulumi.Input[builtins.str] description: Volume description
        :param pulumi.Input[builtins.str] image_id: Image ID
        :param pulumi.Input[builtins.str] instance_id: Instance ID
        :param pulumi.Input[builtins.str] name: Volume name
        :param pulumi.Input[builtins.float] size: Volume size
        :param pulumi.Input[builtins.str] snapshot_id: Snapshot ID
        :param pulumi.Input[builtins.str] type: Type of the volume
        :param pulumi.Input[builtins.str] volume_id: Volume ID
        """
        pulumi.set(__self__, "region_name", region_name)
        pulumi.set(__self__, "service_name", service_name)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if image_id is not None:
            pulumi.set(__self__, "image_id", image_id)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if size is not None:
            pulumi.set(__self__, "size", size)
        if snapshot_id is not None:
            pulumi.set(__self__, "snapshot_id", snapshot_id)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if volume_id is not None:
            pulumi.set(__self__, "volume_id", volume_id)

    @property
    @pulumi.getter(name="regionName")
    def region_name(self) -> pulumi.Input[builtins.str]:
        """
        Region name
        """
        return pulumi.get(self, "region_name")

    @region_name.setter
    def region_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "region_name", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Input[builtins.str]:
        """
        Service name
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Volume description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="imageId")
    def image_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Image ID
        """
        return pulumi.get(self, "image_id")

    @image_id.setter
    def image_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "image_id", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Instance ID
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Volume name
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def size(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        Volume size
        """
        return pulumi.get(self, "size")

    @size.setter
    def size(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "size", value)

    @property
    @pulumi.getter(name="snapshotId")
    def snapshot_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Snapshot ID
        """
        return pulumi.get(self, "snapshot_id")

    @snapshot_id.setter
    def snapshot_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "snapshot_id", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Type of the volume
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter(name="volumeId")
    def volume_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Volume ID
        """
        return pulumi.get(self, "volume_id")

    @volume_id.setter
    def volume_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "volume_id", value)


@pulumi.input_type
class _VolumeState:
    def __init__(__self__, *,
                 action: Optional[pulumi.Input[builtins.str]] = None,
                 completed_at: Optional[pulumi.Input[builtins.str]] = None,
                 created_at: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 image_id: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 progress: Optional[pulumi.Input[builtins.float]] = None,
                 region_name: Optional[pulumi.Input[builtins.str]] = None,
                 regions: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 resource_id: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 size: Optional[pulumi.Input[builtins.float]] = None,
                 snapshot_id: Optional[pulumi.Input[builtins.str]] = None,
                 started_at: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 sub_operations: Optional[pulumi.Input[Sequence[pulumi.Input['VolumeSubOperationArgs']]]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 volume_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Volume resources.
        :param pulumi.Input[builtins.str] action: The action of the operation
        :param pulumi.Input[builtins.str] completed_at: The completed date of the operation
        :param pulumi.Input[builtins.str] created_at: The creation date of the operation
        :param pulumi.Input[builtins.str] description: Volume description
        :param pulumi.Input[builtins.str] image_id: Image ID
        :param pulumi.Input[builtins.str] instance_id: Instance ID
        :param pulumi.Input[builtins.str] name: Volume name
        :param pulumi.Input[builtins.float] progress: Volume status
        :param pulumi.Input[builtins.str] region_name: Region name
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] regions: List of regions
        :param pulumi.Input[builtins.str] resource_id: Id of the resource
        :param pulumi.Input[builtins.str] service_name: Service name
        :param pulumi.Input[builtins.float] size: Volume size
        :param pulumi.Input[builtins.str] snapshot_id: Snapshot ID
        :param pulumi.Input[builtins.str] started_at: Datetime of the operation creation
        :param pulumi.Input[builtins.str] status: Volume status
        :param pulumi.Input[Sequence[pulumi.Input['VolumeSubOperationArgs']]] sub_operations: Sub-operations of the operation
        :param pulumi.Input[builtins.str] type: Type of the volume
        :param pulumi.Input[builtins.str] volume_id: Volume ID
        """
        if action is not None:
            pulumi.set(__self__, "action", action)
        if completed_at is not None:
            pulumi.set(__self__, "completed_at", completed_at)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if image_id is not None:
            pulumi.set(__self__, "image_id", image_id)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if progress is not None:
            pulumi.set(__self__, "progress", progress)
        if region_name is not None:
            pulumi.set(__self__, "region_name", region_name)
        if regions is not None:
            pulumi.set(__self__, "regions", regions)
        if resource_id is not None:
            pulumi.set(__self__, "resource_id", resource_id)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if size is not None:
            pulumi.set(__self__, "size", size)
        if snapshot_id is not None:
            pulumi.set(__self__, "snapshot_id", snapshot_id)
        if started_at is not None:
            pulumi.set(__self__, "started_at", started_at)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if sub_operations is not None:
            pulumi.set(__self__, "sub_operations", sub_operations)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if volume_id is not None:
            pulumi.set(__self__, "volume_id", volume_id)

    @property
    @pulumi.getter
    def action(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The action of the operation
        """
        return pulumi.get(self, "action")

    @action.setter
    def action(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "action", value)

    @property
    @pulumi.getter(name="completedAt")
    def completed_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The completed date of the operation
        """
        return pulumi.get(self, "completed_at")

    @completed_at.setter
    def completed_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "completed_at", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The creation date of the operation
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Volume description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="imageId")
    def image_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Image ID
        """
        return pulumi.get(self, "image_id")

    @image_id.setter
    def image_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "image_id", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Instance ID
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Volume name
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def progress(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        Volume status
        """
        return pulumi.get(self, "progress")

    @progress.setter
    def progress(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "progress", value)

    @property
    @pulumi.getter(name="regionName")
    def region_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Region name
        """
        return pulumi.get(self, "region_name")

    @region_name.setter
    def region_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "region_name", value)

    @property
    @pulumi.getter
    def regions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        List of regions
        """
        return pulumi.get(self, "regions")

    @regions.setter
    def regions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "regions", value)

    @property
    @pulumi.getter(name="resourceId")
    def resource_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Id of the resource
        """
        return pulumi.get(self, "resource_id")

    @resource_id.setter
    def resource_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_id", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Service name
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter
    def size(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        Volume size
        """
        return pulumi.get(self, "size")

    @size.setter
    def size(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "size", value)

    @property
    @pulumi.getter(name="snapshotId")
    def snapshot_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Snapshot ID
        """
        return pulumi.get(self, "snapshot_id")

    @snapshot_id.setter
    def snapshot_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "snapshot_id", value)

    @property
    @pulumi.getter(name="startedAt")
    def started_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Datetime of the operation creation
        """
        return pulumi.get(self, "started_at")

    @started_at.setter
    def started_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "started_at", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Volume status
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="subOperations")
    def sub_operations(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['VolumeSubOperationArgs']]]]:
        """
        Sub-operations of the operation
        """
        return pulumi.get(self, "sub_operations")

    @sub_operations.setter
    def sub_operations(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['VolumeSubOperationArgs']]]]):
        pulumi.set(self, "sub_operations", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Type of the volume
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter(name="volumeId")
    def volume_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Volume ID
        """
        return pulumi.get(self, "volume_id")

    @volume_id.setter
    def volume_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "volume_id", value)


class Volume(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 image_id: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 region_name: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 size: Optional[pulumi.Input[builtins.float]] = None,
                 snapshot_id: Optional[pulumi.Input[builtins.str]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 volume_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Create a Volume resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] description: Volume description
        :param pulumi.Input[builtins.str] image_id: Image ID
        :param pulumi.Input[builtins.str] instance_id: Instance ID
        :param pulumi.Input[builtins.str] name: Volume name
        :param pulumi.Input[builtins.str] region_name: Region name
        :param pulumi.Input[builtins.str] service_name: Service name
        :param pulumi.Input[builtins.float] size: Volume size
        :param pulumi.Input[builtins.str] snapshot_id: Snapshot ID
        :param pulumi.Input[builtins.str] type: Type of the volume
        :param pulumi.Input[builtins.str] volume_id: Volume ID
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: VolumeArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create a Volume resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param VolumeArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(VolumeArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 image_id: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 region_name: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 size: Optional[pulumi.Input[builtins.float]] = None,
                 snapshot_id: Optional[pulumi.Input[builtins.str]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 volume_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = VolumeArgs.__new__(VolumeArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["image_id"] = image_id
            __props__.__dict__["instance_id"] = instance_id
            __props__.__dict__["name"] = name
            if region_name is None and not opts.urn:
                raise TypeError("Missing required property 'region_name'")
            __props__.__dict__["region_name"] = region_name
            if service_name is None and not opts.urn:
                raise TypeError("Missing required property 'service_name'")
            __props__.__dict__["service_name"] = service_name
            __props__.__dict__["size"] = size
            __props__.__dict__["snapshot_id"] = snapshot_id
            __props__.__dict__["type"] = type
            __props__.__dict__["volume_id"] = volume_id
            __props__.__dict__["action"] = None
            __props__.__dict__["completed_at"] = None
            __props__.__dict__["created_at"] = None
            __props__.__dict__["progress"] = None
            __props__.__dict__["regions"] = None
            __props__.__dict__["resource_id"] = None
            __props__.__dict__["started_at"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["sub_operations"] = None
        super(Volume, __self__).__init__(
            'ovh:CloudProject/volume:Volume',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            action: Optional[pulumi.Input[builtins.str]] = None,
            completed_at: Optional[pulumi.Input[builtins.str]] = None,
            created_at: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            image_id: Optional[pulumi.Input[builtins.str]] = None,
            instance_id: Optional[pulumi.Input[builtins.str]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            progress: Optional[pulumi.Input[builtins.float]] = None,
            region_name: Optional[pulumi.Input[builtins.str]] = None,
            regions: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            resource_id: Optional[pulumi.Input[builtins.str]] = None,
            service_name: Optional[pulumi.Input[builtins.str]] = None,
            size: Optional[pulumi.Input[builtins.float]] = None,
            snapshot_id: Optional[pulumi.Input[builtins.str]] = None,
            started_at: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            sub_operations: Optional[pulumi.Input[Sequence[pulumi.Input[Union['VolumeSubOperationArgs', 'VolumeSubOperationArgsDict']]]]] = None,
            type: Optional[pulumi.Input[builtins.str]] = None,
            volume_id: Optional[pulumi.Input[builtins.str]] = None) -> 'Volume':
        """
        Get an existing Volume resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] action: The action of the operation
        :param pulumi.Input[builtins.str] completed_at: The completed date of the operation
        :param pulumi.Input[builtins.str] created_at: The creation date of the operation
        :param pulumi.Input[builtins.str] description: Volume description
        :param pulumi.Input[builtins.str] image_id: Image ID
        :param pulumi.Input[builtins.str] instance_id: Instance ID
        :param pulumi.Input[builtins.str] name: Volume name
        :param pulumi.Input[builtins.float] progress: Volume status
        :param pulumi.Input[builtins.str] region_name: Region name
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] regions: List of regions
        :param pulumi.Input[builtins.str] resource_id: Id of the resource
        :param pulumi.Input[builtins.str] service_name: Service name
        :param pulumi.Input[builtins.float] size: Volume size
        :param pulumi.Input[builtins.str] snapshot_id: Snapshot ID
        :param pulumi.Input[builtins.str] started_at: Datetime of the operation creation
        :param pulumi.Input[builtins.str] status: Volume status
        :param pulumi.Input[Sequence[pulumi.Input[Union['VolumeSubOperationArgs', 'VolumeSubOperationArgsDict']]]] sub_operations: Sub-operations of the operation
        :param pulumi.Input[builtins.str] type: Type of the volume
        :param pulumi.Input[builtins.str] volume_id: Volume ID
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _VolumeState.__new__(_VolumeState)

        __props__.__dict__["action"] = action
        __props__.__dict__["completed_at"] = completed_at
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["description"] = description
        __props__.__dict__["image_id"] = image_id
        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["name"] = name
        __props__.__dict__["progress"] = progress
        __props__.__dict__["region_name"] = region_name
        __props__.__dict__["regions"] = regions
        __props__.__dict__["resource_id"] = resource_id
        __props__.__dict__["service_name"] = service_name
        __props__.__dict__["size"] = size
        __props__.__dict__["snapshot_id"] = snapshot_id
        __props__.__dict__["started_at"] = started_at
        __props__.__dict__["status"] = status
        __props__.__dict__["sub_operations"] = sub_operations
        __props__.__dict__["type"] = type
        __props__.__dict__["volume_id"] = volume_id
        return Volume(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def action(self) -> pulumi.Output[builtins.str]:
        """
        The action of the operation
        """
        return pulumi.get(self, "action")

    @property
    @pulumi.getter(name="completedAt")
    def completed_at(self) -> pulumi.Output[builtins.str]:
        """
        The completed date of the operation
        """
        return pulumi.get(self, "completed_at")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[builtins.str]:
        """
        The creation date of the operation
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        Volume description
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="imageId")
    def image_id(self) -> pulumi.Output[builtins.str]:
        """
        Image ID
        """
        return pulumi.get(self, "image_id")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[builtins.str]:
        """
        Instance ID
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        Volume name
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def progress(self) -> pulumi.Output[builtins.float]:
        """
        Volume status
        """
        return pulumi.get(self, "progress")

    @property
    @pulumi.getter(name="regionName")
    def region_name(self) -> pulumi.Output[builtins.str]:
        """
        Region name
        """
        return pulumi.get(self, "region_name")

    @property
    @pulumi.getter
    def regions(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        List of regions
        """
        return pulumi.get(self, "regions")

    @property
    @pulumi.getter(name="resourceId")
    def resource_id(self) -> pulumi.Output[builtins.str]:
        """
        Id of the resource
        """
        return pulumi.get(self, "resource_id")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[builtins.str]:
        """
        Service name
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter
    def size(self) -> pulumi.Output[builtins.float]:
        """
        Volume size
        """
        return pulumi.get(self, "size")

    @property
    @pulumi.getter(name="snapshotId")
    def snapshot_id(self) -> pulumi.Output[builtins.str]:
        """
        Snapshot ID
        """
        return pulumi.get(self, "snapshot_id")

    @property
    @pulumi.getter(name="startedAt")
    def started_at(self) -> pulumi.Output[builtins.str]:
        """
        Datetime of the operation creation
        """
        return pulumi.get(self, "started_at")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        Volume status
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="subOperations")
    def sub_operations(self) -> pulumi.Output[Sequence['outputs.VolumeSubOperation']]:
        """
        Sub-operations of the operation
        """
        return pulumi.get(self, "sub_operations")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[builtins.str]:
        """
        Type of the volume
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="volumeId")
    def volume_id(self) -> pulumi.Output[builtins.str]:
        """
        Volume ID
        """
        return pulumi.get(self, "volume_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetMeResult',
    'AwaitableGetMeResult',
    'get_me',
    'get_me_output',
]

@pulumi.output_type
class GetMeResult:
    """
    A collection of values returned by getMe.
    """
    def __init__(__self__, account_urn=None, address=None, area=None, birth_city=None, birth_day=None, city=None, company_national_identification_number=None, corporation_type=None, country=None, currencies=None, customer_code=None, email=None, fax=None, firstname=None, id=None, italian_sdi=None, language=None, legalform=None, name=None, national_identification_number=None, nichandle=None, organisation=None, ovh_company=None, ovh_subsidiary=None, phone=None, phone_country=None, sex=None, spare_email=None, state=None, vat=None, zip=None):
        if account_urn and not isinstance(account_urn, str):
            raise TypeError("Expected argument 'account_urn' to be a str")
        pulumi.set(__self__, "account_urn", account_urn)
        if address and not isinstance(address, str):
            raise TypeError("Expected argument 'address' to be a str")
        pulumi.set(__self__, "address", address)
        if area and not isinstance(area, str):
            raise TypeError("Expected argument 'area' to be a str")
        pulumi.set(__self__, "area", area)
        if birth_city and not isinstance(birth_city, str):
            raise TypeError("Expected argument 'birth_city' to be a str")
        pulumi.set(__self__, "birth_city", birth_city)
        if birth_day and not isinstance(birth_day, str):
            raise TypeError("Expected argument 'birth_day' to be a str")
        pulumi.set(__self__, "birth_day", birth_day)
        if city and not isinstance(city, str):
            raise TypeError("Expected argument 'city' to be a str")
        pulumi.set(__self__, "city", city)
        if company_national_identification_number and not isinstance(company_national_identification_number, str):
            raise TypeError("Expected argument 'company_national_identification_number' to be a str")
        pulumi.set(__self__, "company_national_identification_number", company_national_identification_number)
        if corporation_type and not isinstance(corporation_type, str):
            raise TypeError("Expected argument 'corporation_type' to be a str")
        pulumi.set(__self__, "corporation_type", corporation_type)
        if country and not isinstance(country, str):
            raise TypeError("Expected argument 'country' to be a str")
        pulumi.set(__self__, "country", country)
        if currencies and not isinstance(currencies, list):
            raise TypeError("Expected argument 'currencies' to be a list")
        pulumi.set(__self__, "currencies", currencies)
        if customer_code and not isinstance(customer_code, str):
            raise TypeError("Expected argument 'customer_code' to be a str")
        pulumi.set(__self__, "customer_code", customer_code)
        if email and not isinstance(email, str):
            raise TypeError("Expected argument 'email' to be a str")
        pulumi.set(__self__, "email", email)
        if fax and not isinstance(fax, str):
            raise TypeError("Expected argument 'fax' to be a str")
        pulumi.set(__self__, "fax", fax)
        if firstname and not isinstance(firstname, str):
            raise TypeError("Expected argument 'firstname' to be a str")
        pulumi.set(__self__, "firstname", firstname)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if italian_sdi and not isinstance(italian_sdi, str):
            raise TypeError("Expected argument 'italian_sdi' to be a str")
        pulumi.set(__self__, "italian_sdi", italian_sdi)
        if language and not isinstance(language, str):
            raise TypeError("Expected argument 'language' to be a str")
        pulumi.set(__self__, "language", language)
        if legalform and not isinstance(legalform, str):
            raise TypeError("Expected argument 'legalform' to be a str")
        pulumi.set(__self__, "legalform", legalform)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if national_identification_number and not isinstance(national_identification_number, str):
            raise TypeError("Expected argument 'national_identification_number' to be a str")
        pulumi.set(__self__, "national_identification_number", national_identification_number)
        if nichandle and not isinstance(nichandle, str):
            raise TypeError("Expected argument 'nichandle' to be a str")
        pulumi.set(__self__, "nichandle", nichandle)
        if organisation and not isinstance(organisation, str):
            raise TypeError("Expected argument 'organisation' to be a str")
        pulumi.set(__self__, "organisation", organisation)
        if ovh_company and not isinstance(ovh_company, str):
            raise TypeError("Expected argument 'ovh_company' to be a str")
        pulumi.set(__self__, "ovh_company", ovh_company)
        if ovh_subsidiary and not isinstance(ovh_subsidiary, str):
            raise TypeError("Expected argument 'ovh_subsidiary' to be a str")
        pulumi.set(__self__, "ovh_subsidiary", ovh_subsidiary)
        if phone and not isinstance(phone, str):
            raise TypeError("Expected argument 'phone' to be a str")
        pulumi.set(__self__, "phone", phone)
        if phone_country and not isinstance(phone_country, str):
            raise TypeError("Expected argument 'phone_country' to be a str")
        pulumi.set(__self__, "phone_country", phone_country)
        if sex and not isinstance(sex, str):
            raise TypeError("Expected argument 'sex' to be a str")
        pulumi.set(__self__, "sex", sex)
        if spare_email and not isinstance(spare_email, str):
            raise TypeError("Expected argument 'spare_email' to be a str")
        pulumi.set(__self__, "spare_email", spare_email)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if vat and not isinstance(vat, str):
            raise TypeError("Expected argument 'vat' to be a str")
        pulumi.set(__self__, "vat", vat)
        if zip and not isinstance(zip, str):
            raise TypeError("Expected argument 'zip' to be a str")
        pulumi.set(__self__, "zip", zip)

    @property
    @pulumi.getter(name="AccountURN")
    def account_urn(self) -> builtins.str:
        """
        The resource URN of the account, to be used when writing IAM policies
        """
        return pulumi.get(self, "account_urn")

    @property
    @pulumi.getter
    def address(self) -> builtins.str:
        """
        Postal address of the account
        """
        return pulumi.get(self, "address")

    @property
    @pulumi.getter
    def area(self) -> builtins.str:
        """
        Area of the account
        """
        return pulumi.get(self, "area")

    @property
    @pulumi.getter(name="birthCity")
    def birth_city(self) -> builtins.str:
        """
        City of birth
        """
        return pulumi.get(self, "birth_city")

    @property
    @pulumi.getter(name="birthDay")
    def birth_day(self) -> builtins.str:
        """
        Birth date
        """
        return pulumi.get(self, "birth_day")

    @property
    @pulumi.getter
    def city(self) -> builtins.str:
        """
        City of the account
        """
        return pulumi.get(self, "city")

    @property
    @pulumi.getter(name="companyNationalIdentificationNumber")
    def company_national_identification_number(self) -> builtins.str:
        """
        This is the national identification number of the company that possess this account
        """
        return pulumi.get(self, "company_national_identification_number")

    @property
    @pulumi.getter(name="corporationType")
    def corporation_type(self) -> builtins.str:
        """
        Type of corporation
        """
        return pulumi.get(self, "corporation_type")

    @property
    @pulumi.getter
    def country(self) -> builtins.str:
        """
        Country of the account
        """
        return pulumi.get(self, "country")

    @property
    @pulumi.getter
    def currencies(self) -> Sequence['outputs.GetMeCurrencyResult']:
        return pulumi.get(self, "currencies")

    @property
    @pulumi.getter(name="customerCode")
    def customer_code(self) -> builtins.str:
        """
        The customer code of this account (a numerical value used for identification when contacting support via phone call)
        """
        return pulumi.get(self, "customer_code")

    @property
    @pulumi.getter
    def email(self) -> builtins.str:
        """
        Email address
        """
        return pulumi.get(self, "email")

    @property
    @pulumi.getter
    def fax(self) -> builtins.str:
        """
        Fax number
        """
        return pulumi.get(self, "fax")

    @property
    @pulumi.getter
    def firstname(self) -> builtins.str:
        """
        First name
        """
        return pulumi.get(self, "firstname")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="italianSdi")
    def italian_sdi(self) -> builtins.str:
        """
        Italian SDI
        """
        return pulumi.get(self, "italian_sdi")

    @property
    @pulumi.getter
    def language(self) -> builtins.str:
        """
        Preferred language for this account
        """
        return pulumi.get(self, "language")

    @property
    @pulumi.getter
    def legalform(self) -> builtins.str:
        """
        Legal form of the account
        """
        return pulumi.get(self, "legalform")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        Name of the account holder
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="nationalIdentificationNumber")
    def national_identification_number(self) -> builtins.str:
        """
        National Identification Number of this account
        """
        return pulumi.get(self, "national_identification_number")

    @property
    @pulumi.getter
    def nichandle(self) -> builtins.str:
        """
        Nic handle / customer identifier
        """
        return pulumi.get(self, "nichandle")

    @property
    @pulumi.getter
    def organisation(self) -> builtins.str:
        """
        Name of the organisation for this account
        """
        return pulumi.get(self, "organisation")

    @property
    @pulumi.getter(name="ovhCompany")
    def ovh_company(self) -> builtins.str:
        """
        OVHcloud subsidiary
        """
        return pulumi.get(self, "ovh_company")

    @property
    @pulumi.getter(name="ovhSubsidiary")
    def ovh_subsidiary(self) -> builtins.str:
        """
        OVHcloud subsidiary
        """
        return pulumi.get(self, "ovh_subsidiary")

    @property
    @pulumi.getter
    def phone(self) -> builtins.str:
        """
        Phone number
        """
        return pulumi.get(self, "phone")

    @property
    @pulumi.getter(name="phoneCountry")
    def phone_country(self) -> builtins.str:
        """
        Country code of the phone number
        """
        return pulumi.get(self, "phone_country")

    @property
    @pulumi.getter
    def sex(self) -> builtins.str:
        """
        Gender of the account holder
        """
        return pulumi.get(self, "sex")

    @property
    @pulumi.getter(name="spareEmail")
    def spare_email(self) -> builtins.str:
        """
        Backup email address
        """
        return pulumi.get(self, "spare_email")

    @property
    @pulumi.getter
    def state(self) -> builtins.str:
        """
        State of the postal address
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter
    def vat(self) -> builtins.str:
        """
        VAT number
        """
        return pulumi.get(self, "vat")

    @property
    @pulumi.getter
    def zip(self) -> builtins.str:
        """
        Zipcode of the address
        """
        return pulumi.get(self, "zip")


class AwaitableGetMeResult(GetMeResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetMeResult(
            account_urn=self.account_urn,
            address=self.address,
            area=self.area,
            birth_city=self.birth_city,
            birth_day=self.birth_day,
            city=self.city,
            company_national_identification_number=self.company_national_identification_number,
            corporation_type=self.corporation_type,
            country=self.country,
            currencies=self.currencies,
            customer_code=self.customer_code,
            email=self.email,
            fax=self.fax,
            firstname=self.firstname,
            id=self.id,
            italian_sdi=self.italian_sdi,
            language=self.language,
            legalform=self.legalform,
            name=self.name,
            national_identification_number=self.national_identification_number,
            nichandle=self.nichandle,
            organisation=self.organisation,
            ovh_company=self.ovh_company,
            ovh_subsidiary=self.ovh_subsidiary,
            phone=self.phone,
            phone_country=self.phone_country,
            sex=self.sex,
            spare_email=self.spare_email,
            state=self.state,
            vat=self.vat,
            zip=self.zip)


def get_me(opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetMeResult:
    """
    Use this data source to get information about the current OVHcloud account.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    my_account = ovh.Me.get_me()
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:Me/getMe:getMe', __args__, opts=opts, typ=GetMeResult).value

    return AwaitableGetMeResult(
        account_urn=pulumi.get(__ret__, 'account_urn'),
        address=pulumi.get(__ret__, 'address'),
        area=pulumi.get(__ret__, 'area'),
        birth_city=pulumi.get(__ret__, 'birth_city'),
        birth_day=pulumi.get(__ret__, 'birth_day'),
        city=pulumi.get(__ret__, 'city'),
        company_national_identification_number=pulumi.get(__ret__, 'company_national_identification_number'),
        corporation_type=pulumi.get(__ret__, 'corporation_type'),
        country=pulumi.get(__ret__, 'country'),
        currencies=pulumi.get(__ret__, 'currencies'),
        customer_code=pulumi.get(__ret__, 'customer_code'),
        email=pulumi.get(__ret__, 'email'),
        fax=pulumi.get(__ret__, 'fax'),
        firstname=pulumi.get(__ret__, 'firstname'),
        id=pulumi.get(__ret__, 'id'),
        italian_sdi=pulumi.get(__ret__, 'italian_sdi'),
        language=pulumi.get(__ret__, 'language'),
        legalform=pulumi.get(__ret__, 'legalform'),
        name=pulumi.get(__ret__, 'name'),
        national_identification_number=pulumi.get(__ret__, 'national_identification_number'),
        nichandle=pulumi.get(__ret__, 'nichandle'),
        organisation=pulumi.get(__ret__, 'organisation'),
        ovh_company=pulumi.get(__ret__, 'ovh_company'),
        ovh_subsidiary=pulumi.get(__ret__, 'ovh_subsidiary'),
        phone=pulumi.get(__ret__, 'phone'),
        phone_country=pulumi.get(__ret__, 'phone_country'),
        sex=pulumi.get(__ret__, 'sex'),
        spare_email=pulumi.get(__ret__, 'spare_email'),
        state=pulumi.get(__ret__, 'state'),
        vat=pulumi.get(__ret__, 'vat'),
        zip=pulumi.get(__ret__, 'zip'))
def get_me_output(opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetMeResult]:
    """
    Use this data source to get information about the current OVHcloud account.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    my_account = ovh.Me.get_me()
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:Me/getMe:getMe', __args__, opts=opts, typ=GetMeResult)
    return __ret__.apply(lambda __response__: GetMeResult(
        account_urn=pulumi.get(__response__, 'account_urn'),
        address=pulumi.get(__response__, 'address'),
        area=pulumi.get(__response__, 'area'),
        birth_city=pulumi.get(__response__, 'birth_city'),
        birth_day=pulumi.get(__response__, 'birth_day'),
        city=pulumi.get(__response__, 'city'),
        company_national_identification_number=pulumi.get(__response__, 'company_national_identification_number'),
        corporation_type=pulumi.get(__response__, 'corporation_type'),
        country=pulumi.get(__response__, 'country'),
        currencies=pulumi.get(__response__, 'currencies'),
        customer_code=pulumi.get(__response__, 'customer_code'),
        email=pulumi.get(__response__, 'email'),
        fax=pulumi.get(__response__, 'fax'),
        firstname=pulumi.get(__response__, 'firstname'),
        id=pulumi.get(__response__, 'id'),
        italian_sdi=pulumi.get(__response__, 'italian_sdi'),
        language=pulumi.get(__response__, 'language'),
        legalform=pulumi.get(__response__, 'legalform'),
        name=pulumi.get(__response__, 'name'),
        national_identification_number=pulumi.get(__response__, 'national_identification_number'),
        nichandle=pulumi.get(__response__, 'nichandle'),
        organisation=pulumi.get(__response__, 'organisation'),
        ovh_company=pulumi.get(__response__, 'ovh_company'),
        ovh_subsidiary=pulumi.get(__response__, 'ovh_subsidiary'),
        phone=pulumi.get(__response__, 'phone'),
        phone_country=pulumi.get(__response__, 'phone_country'),
        sex=pulumi.get(__response__, 'sex'),
        spare_email=pulumi.get(__response__, 'spare_email'),
        state=pulumi.get(__response__, 'state'),
        vat=pulumi.get(__response__, 'vat'),
        zip=pulumi.get(__response__, 'zip')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetNetworkPrivateResult',
    'AwaitableGetNetworkPrivateResult',
    'get_network_private',
    'get_network_private_output',
]

@pulumi.output_type
class GetNetworkPrivateResult:
    """
    A collection of values returned by getNetworkPrivate.
    """
    def __init__(__self__, id=None, name=None, network_id=None, regions=None, service_name=None, status=None, type=None, vlan_id=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if network_id and not isinstance(network_id, str):
            raise TypeError("Expected argument 'network_id' to be a str")
        pulumi.set(__self__, "network_id", network_id)
        if regions and not isinstance(regions, list):
            raise TypeError("Expected argument 'regions' to be a list")
        pulumi.set(__self__, "regions", regions)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)
        if vlan_id and not isinstance(vlan_id, float):
            raise TypeError("Expected argument 'vlan_id' to be a float")
        pulumi.set(__self__, "vlan_id", vlan_id)

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        Name of the network
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="networkId")
    def network_id(self) -> builtins.str:
        """
        ID of the network
        """
        return pulumi.get(self, "network_id")

    @property
    @pulumi.getter
    def regions(self) -> Sequence['outputs.GetNetworkPrivateRegionResult']:
        """
        Information about the private network in the openstack region
        """
        return pulumi.get(self, "regions")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> builtins.str:
        """
        ID of the public cloud project
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        Status of the network
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def type(self) -> builtins.str:
        """
        Type of the network
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="vlanId")
    def vlan_id(self) -> builtins.float:
        """
        VLAN ID of the network
        """
        return pulumi.get(self, "vlan_id")


class AwaitableGetNetworkPrivateResult(GetNetworkPrivateResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetNetworkPrivateResult(
            id=self.id,
            name=self.name,
            network_id=self.network_id,
            regions=self.regions,
            service_name=self.service_name,
            status=self.status,
            type=self.type,
            vlan_id=self.vlan_id)


def get_network_private(network_id: Optional[builtins.str] = None,
                        service_name: Optional[builtins.str] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetNetworkPrivateResult:
    """
    Get the details of a public cloud project private network.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    private = ovh.CloudProject.get_network_private(service_name="XXXXXX",
        network_id="XXX")
    pulumi.export("private", private)
    ```


    :param builtins.str network_id: ID of the network
    :param builtins.str service_name: The ID of the public cloud project.
    """
    __args__ = dict()
    __args__['networkId'] = network_id
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:CloudProject/getNetworkPrivate:getNetworkPrivate', __args__, opts=opts, typ=GetNetworkPrivateResult).value

    return AwaitableGetNetworkPrivateResult(
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        network_id=pulumi.get(__ret__, 'network_id'),
        regions=pulumi.get(__ret__, 'regions'),
        service_name=pulumi.get(__ret__, 'service_name'),
        status=pulumi.get(__ret__, 'status'),
        type=pulumi.get(__ret__, 'type'),
        vlan_id=pulumi.get(__ret__, 'vlan_id'))
def get_network_private_output(network_id: Optional[pulumi.Input[builtins.str]] = None,
                               service_name: Optional[pulumi.Input[builtins.str]] = None,
                               opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetNetworkPrivateResult]:
    """
    Get the details of a public cloud project private network.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    private = ovh.CloudProject.get_network_private(service_name="XXXXXX",
        network_id="XXX")
    pulumi.export("private", private)
    ```


    :param builtins.str network_id: ID of the network
    :param builtins.str service_name: The ID of the public cloud project.
    """
    __args__ = dict()
    __args__['networkId'] = network_id
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:CloudProject/getNetworkPrivate:getNetworkPrivate', __args__, opts=opts, typ=GetNetworkPrivateResult)
    return __ret__.apply(lambda __response__: GetNetworkPrivateResult(
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        network_id=pulumi.get(__response__, 'network_id'),
        regions=pulumi.get(__response__, 'regions'),
        service_name=pulumi.get(__response__, 'service_name'),
        status=pulumi.get(__response__, 'status'),
        type=pulumi.get(__response__, 'type'),
        vlan_id=pulumi.get(__response__, 'vlan_id')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'DSRecordsDsRecord',
    'NameCurrentState',
    'NameCurrentStateDnsConfiguration',
    'NameCurrentStateDnsConfigurationNameServer',
    'NameCurrentTask',
    'NameIam',
    'NameOrder',
    'NameOrderDetail',
    'NamePlan',
    'NamePlanConfiguration',
    'NamePlanOption',
    'NamePlanOptionConfiguration',
    'NameServersServer',
    'NameTargetSpec',
    'NameTargetSpecDnsConfiguration',
    'NameTargetSpecDnsConfigurationNameServer',
    'ZoneOrder',
    'ZoneOrderDetail',
    'ZonePlan',
    'ZonePlanConfiguration',
    'ZonePlanOption',
    'ZonePlanOptionConfiguration',
]

@pulumi.output_type
class DSRecordsDsRecord(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "publicKey":
            suggest = "public_key"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in DSRecordsDsRecord. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        DSRecordsDsRecord.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        DSRecordsDsRecord.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 algorithm: builtins.str,
                 flags: builtins.str,
                 public_key: builtins.str,
                 tag: builtins.int):
        """
        :param builtins.str algorithm: The record algorithm (`RSASHA1`, `RSASHA1_NSEC3_SHA1`, `RSASHA256`, `RSASHA512`, `ECDSAP256SHA256`, `ECDSAP384SHA384`, `ED25519`)
        :param builtins.str flags: The record flag (`ZONE_SIGNING_KEY`, `KEY_SIGNING_KEY`)
        :param builtins.str public_key: The record base64 encoded public key
        :param builtins.int tag: The record tag
        """
        pulumi.set(__self__, "algorithm", algorithm)
        pulumi.set(__self__, "flags", flags)
        pulumi.set(__self__, "public_key", public_key)
        pulumi.set(__self__, "tag", tag)

    @property
    @pulumi.getter
    def algorithm(self) -> builtins.str:
        """
        The record algorithm (`RSASHA1`, `RSASHA1_NSEC3_SHA1`, `RSASHA256`, `RSASHA512`, `ECDSAP256SHA256`, `ECDSAP384SHA384`, `ED25519`)
        """
        return pulumi.get(self, "algorithm")

    @property
    @pulumi.getter
    def flags(self) -> builtins.str:
        """
        The record flag (`ZONE_SIGNING_KEY`, `KEY_SIGNING_KEY`)
        """
        return pulumi.get(self, "flags")

    @property
    @pulumi.getter(name="publicKey")
    def public_key(self) -> builtins.str:
        """
        The record base64 encoded public key
        """
        return pulumi.get(self, "public_key")

    @property
    @pulumi.getter
    def tag(self) -> builtins.int:
        """
        The record tag
        """
        return pulumi.get(self, "tag")


@pulumi.output_type
class NameCurrentState(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "additionalStates":
            suggest = "additional_states"
        elif key == "dnsConfiguration":
            suggest = "dns_configuration"
        elif key == "mainState":
            suggest = "main_state"
        elif key == "protectionState":
            suggest = "protection_state"
        elif key == "suspensionState":
            suggest = "suspension_state"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in NameCurrentState. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        NameCurrentState.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        NameCurrentState.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 additional_states: Optional[Sequence[builtins.str]] = None,
                 dns_configuration: Optional['outputs.NameCurrentStateDnsConfiguration'] = None,
                 extension: Optional[builtins.str] = None,
                 main_state: Optional[builtins.str] = None,
                 name: Optional[builtins.str] = None,
                 protection_state: Optional[builtins.str] = None,
                 suspension_state: Optional[builtins.str] = None):
        """
        :param Sequence[builtins.str] additional_states: Domain additional states
        :param 'NameCurrentStateDnsConfigurationArgs' dns_configuration: The domain DNS configuration
        :param builtins.str extension: Extension of the domain name
        :param builtins.str main_state: Domain main state
        :param builtins.str name: Domain name
        :param builtins.str protection_state: Domain protection state
        :param builtins.str suspension_state: Domain suspension state
        """
        if additional_states is not None:
            pulumi.set(__self__, "additional_states", additional_states)
        if dns_configuration is not None:
            pulumi.set(__self__, "dns_configuration", dns_configuration)
        if extension is not None:
            pulumi.set(__self__, "extension", extension)
        if main_state is not None:
            pulumi.set(__self__, "main_state", main_state)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if protection_state is not None:
            pulumi.set(__self__, "protection_state", protection_state)
        if suspension_state is not None:
            pulumi.set(__self__, "suspension_state", suspension_state)

    @property
    @pulumi.getter(name="additionalStates")
    def additional_states(self) -> Optional[Sequence[builtins.str]]:
        """
        Domain additional states
        """
        return pulumi.get(self, "additional_states")

    @property
    @pulumi.getter(name="dnsConfiguration")
    def dns_configuration(self) -> Optional['outputs.NameCurrentStateDnsConfiguration']:
        """
        The domain DNS configuration
        """
        return pulumi.get(self, "dns_configuration")

    @property
    @pulumi.getter
    def extension(self) -> Optional[builtins.str]:
        """
        Extension of the domain name
        """
        return pulumi.get(self, "extension")

    @property
    @pulumi.getter(name="mainState")
    def main_state(self) -> Optional[builtins.str]:
        """
        Domain main state
        """
        return pulumi.get(self, "main_state")

    @property
    @pulumi.getter
    def name(self) -> Optional[builtins.str]:
        """
        Domain name
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="protectionState")
    def protection_state(self) -> Optional[builtins.str]:
        """
        Domain protection state
        """
        return pulumi.get(self, "protection_state")

    @property
    @pulumi.getter(name="suspensionState")
    def suspension_state(self) -> Optional[builtins.str]:
        """
        Domain suspension state
        """
        return pulumi.get(self, "suspension_state")


@pulumi.output_type
class NameCurrentStateDnsConfiguration(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "configurationType":
            suggest = "configuration_type"
        elif key == "glueRecordIpv6supported":
            suggest = "glue_record_ipv6supported"
        elif key == "hostSupported":
            suggest = "host_supported"
        elif key == "maxDns":
            suggest = "max_dns"
        elif key == "minDns":
            suggest = "min_dns"
        elif key == "nameServers":
            suggest = "name_servers"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in NameCurrentStateDnsConfiguration. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        NameCurrentStateDnsConfiguration.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        NameCurrentStateDnsConfiguration.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 configuration_type: Optional[builtins.str] = None,
                 glue_record_ipv6supported: Optional[builtins.bool] = None,
                 host_supported: Optional[builtins.bool] = None,
                 max_dns: Optional[builtins.float] = None,
                 min_dns: Optional[builtins.float] = None,
                 name_servers: Optional[Sequence['outputs.NameCurrentStateDnsConfigurationNameServer']] = None):
        """
        :param builtins.str configuration_type: The type of DNS configuration of the domain
        :param builtins.bool glue_record_ipv6supported: Whether the registry supports IPv6 or not
        :param builtins.bool host_supported: Whether the registry accepts hosts or not
        :param builtins.float max_dns: The maximum number of name servers allowed by the registry
        :param builtins.float min_dns: The minimum number of name servers allowed by the registry
        :param Sequence['NameCurrentStateDnsConfigurationNameServerArgs'] name_servers: The name servers used by the domain name
        """
        if configuration_type is not None:
            pulumi.set(__self__, "configuration_type", configuration_type)
        if glue_record_ipv6supported is not None:
            pulumi.set(__self__, "glue_record_ipv6supported", glue_record_ipv6supported)
        if host_supported is not None:
            pulumi.set(__self__, "host_supported", host_supported)
        if max_dns is not None:
            pulumi.set(__self__, "max_dns", max_dns)
        if min_dns is not None:
            pulumi.set(__self__, "min_dns", min_dns)
        if name_servers is not None:
            pulumi.set(__self__, "name_servers", name_servers)

    @property
    @pulumi.getter(name="configurationType")
    def configuration_type(self) -> Optional[builtins.str]:
        """
        The type of DNS configuration of the domain
        """
        return pulumi.get(self, "configuration_type")

    @property
    @pulumi.getter(name="glueRecordIpv6supported")
    def glue_record_ipv6supported(self) -> Optional[builtins.bool]:
        """
        Whether the registry supports IPv6 or not
        """
        return pulumi.get(self, "glue_record_ipv6supported")

    @property
    @pulumi.getter(name="hostSupported")
    def host_supported(self) -> Optional[builtins.bool]:
        """
        Whether the registry accepts hosts or not
        """
        return pulumi.get(self, "host_supported")

    @property
    @pulumi.getter(name="maxDns")
    def max_dns(self) -> Optional[builtins.float]:
        """
        The maximum number of name servers allowed by the registry
        """
        return pulumi.get(self, "max_dns")

    @property
    @pulumi.getter(name="minDns")
    def min_dns(self) -> Optional[builtins.float]:
        """
        The minimum number of name servers allowed by the registry
        """
        return pulumi.get(self, "min_dns")

    @property
    @pulumi.getter(name="nameServers")
    def name_servers(self) -> Optional[Sequence['outputs.NameCurrentStateDnsConfigurationNameServer']]:
        """
        The name servers used by the domain name
        """
        return pulumi.get(self, "name_servers")


@pulumi.output_type
class NameCurrentStateDnsConfigurationNameServer(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "nameServer":
            suggest = "name_server"
        elif key == "nameServerType":
            suggest = "name_server_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in NameCurrentStateDnsConfigurationNameServer. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        NameCurrentStateDnsConfigurationNameServer.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        NameCurrentStateDnsConfigurationNameServer.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 ipv4: Optional[builtins.str] = None,
                 ipv6: Optional[builtins.str] = None,
                 name_server: Optional[builtins.str] = None,
                 name_server_type: Optional[builtins.str] = None):
        """
        :param builtins.str ipv4: The IPv4 associated to the name server
        :param builtins.str ipv6: The IPv6 associated to the name server
        :param builtins.str name_server: The host name
        :param builtins.str name_server_type: The type of name server
        """
        if ipv4 is not None:
            pulumi.set(__self__, "ipv4", ipv4)
        if ipv6 is not None:
            pulumi.set(__self__, "ipv6", ipv6)
        if name_server is not None:
            pulumi.set(__self__, "name_server", name_server)
        if name_server_type is not None:
            pulumi.set(__self__, "name_server_type", name_server_type)

    @property
    @pulumi.getter
    def ipv4(self) -> Optional[builtins.str]:
        """
        The IPv4 associated to the name server
        """
        return pulumi.get(self, "ipv4")

    @property
    @pulumi.getter
    def ipv6(self) -> Optional[builtins.str]:
        """
        The IPv6 associated to the name server
        """
        return pulumi.get(self, "ipv6")

    @property
    @pulumi.getter(name="nameServer")
    def name_server(self) -> Optional[builtins.str]:
        """
        The host name
        """
        return pulumi.get(self, "name_server")

    @property
    @pulumi.getter(name="nameServerType")
    def name_server_type(self) -> Optional[builtins.str]:
        """
        The type of name server
        """
        return pulumi.get(self, "name_server_type")


@pulumi.output_type
class NameCurrentTask(dict):
    def __init__(__self__, *,
                 id: Optional[builtins.str] = None,
                 link: Optional[builtins.str] = None,
                 status: Optional[builtins.str] = None,
                 type: Optional[builtins.str] = None):
        """
        :param builtins.str id: Identifier of the current task
        :param builtins.str link: Link to the task details
        :param builtins.str status: Current global status of the current task
        :param builtins.str type: Type of the current task
        """
        if id is not None:
            pulumi.set(__self__, "id", id)
        if link is not None:
            pulumi.set(__self__, "link", link)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def id(self) -> Optional[builtins.str]:
        """
        Identifier of the current task
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def link(self) -> Optional[builtins.str]:
        """
        Link to the task details
        """
        return pulumi.get(self, "link")

    @property
    @pulumi.getter
    def status(self) -> Optional[builtins.str]:
        """
        Current global status of the current task
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def type(self) -> Optional[builtins.str]:
        """
        Type of the current task
        """
        return pulumi.get(self, "type")


@pulumi.output_type
class NameIam(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "displayName":
            suggest = "display_name"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in NameIam. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        NameIam.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        NameIam.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 display_name: Optional[builtins.str] = None,
                 id: Optional[builtins.str] = None,
                 tags: Optional[Mapping[str, builtins.str]] = None,
                 urn: Optional[builtins.str] = None):
        """
        :param builtins.str display_name: Resource display name
        :param builtins.str id: Unique identifier of the resource
        :param Mapping[str, builtins.str] tags: Resource tags. Tags that were internally computed are prefixed with ovh:
        :param builtins.str urn: Unique resource name used in policies
        """
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if urn is not None:
            pulumi.set(__self__, "urn", urn)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[builtins.str]:
        """
        Resource display name
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def id(self) -> Optional[builtins.str]:
        """
        Unique identifier of the resource
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def tags(self) -> Optional[Mapping[str, builtins.str]]:
        """
        Resource tags. Tags that were internally computed are prefixed with ovh:
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def urn(self) -> Optional[builtins.str]:
        """
        Unique resource name used in policies
        """
        return pulumi.get(self, "urn")


@pulumi.output_type
class NameOrder(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "expirationDate":
            suggest = "expiration_date"
        elif key == "orderId":
            suggest = "order_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in NameOrder. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        NameOrder.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        NameOrder.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 date: Optional[builtins.str] = None,
                 details: Optional[Sequence['outputs.NameOrderDetail']] = None,
                 expiration_date: Optional[builtins.str] = None,
                 order_id: Optional[builtins.float] = None):
        if date is not None:
            pulumi.set(__self__, "date", date)
        if details is not None:
            pulumi.set(__self__, "details", details)
        if expiration_date is not None:
            pulumi.set(__self__, "expiration_date", expiration_date)
        if order_id is not None:
            pulumi.set(__self__, "order_id", order_id)

    @property
    @pulumi.getter
    def date(self) -> Optional[builtins.str]:
        return pulumi.get(self, "date")

    @property
    @pulumi.getter
    def details(self) -> Optional[Sequence['outputs.NameOrderDetail']]:
        return pulumi.get(self, "details")

    @property
    @pulumi.getter(name="expirationDate")
    def expiration_date(self) -> Optional[builtins.str]:
        return pulumi.get(self, "expiration_date")

    @property
    @pulumi.getter(name="orderId")
    def order_id(self) -> Optional[builtins.float]:
        return pulumi.get(self, "order_id")


@pulumi.output_type
class NameOrderDetail(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "detailType":
            suggest = "detail_type"
        elif key == "orderDetailId":
            suggest = "order_detail_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in NameOrderDetail. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        NameOrderDetail.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        NameOrderDetail.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 description: Optional[builtins.str] = None,
                 detail_type: Optional[builtins.str] = None,
                 domain: Optional[builtins.str] = None,
                 order_detail_id: Optional[builtins.float] = None,
                 quantity: Optional[builtins.str] = None):
        """
        :param builtins.str detail_type: Product type of item in order
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if detail_type is not None:
            pulumi.set(__self__, "detail_type", detail_type)
        if domain is not None:
            pulumi.set(__self__, "domain", domain)
        if order_detail_id is not None:
            pulumi.set(__self__, "order_detail_id", order_detail_id)
        if quantity is not None:
            pulumi.set(__self__, "quantity", quantity)

    @property
    @pulumi.getter
    def description(self) -> Optional[builtins.str]:
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="detailType")
    def detail_type(self) -> Optional[builtins.str]:
        """
        Product type of item in order
        """
        return pulumi.get(self, "detail_type")

    @property
    @pulumi.getter
    def domain(self) -> Optional[builtins.str]:
        return pulumi.get(self, "domain")

    @property
    @pulumi.getter(name="orderDetailId")
    def order_detail_id(self) -> Optional[builtins.float]:
        return pulumi.get(self, "order_detail_id")

    @property
    @pulumi.getter
    def quantity(self) -> Optional[builtins.str]:
        return pulumi.get(self, "quantity")


@pulumi.output_type
class NamePlan(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "planCode":
            suggest = "plan_code"
        elif key == "pricingMode":
            suggest = "pricing_mode"
        elif key == "itemId":
            suggest = "item_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in NamePlan. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        NamePlan.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        NamePlan.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 duration: builtins.str,
                 plan_code: builtins.str,
                 pricing_mode: builtins.str,
                 configurations: Optional[Sequence['outputs.NamePlanConfiguration']] = None,
                 item_id: Optional[builtins.float] = None,
                 quantity: Optional[builtins.float] = None):
        """
        :param builtins.str duration: Duration selected for the purchase of the product (defaults to "P1Y")
        :param builtins.str plan_code: Identifier of the option offer
        :param builtins.str pricing_mode: Pricing mode selected for the purchase of the product
        :param builtins.float item_id: Cart item to be linked
        :param builtins.float quantity: Quantity of product desired
        """
        pulumi.set(__self__, "duration", duration)
        pulumi.set(__self__, "plan_code", plan_code)
        pulumi.set(__self__, "pricing_mode", pricing_mode)
        if configurations is not None:
            pulumi.set(__self__, "configurations", configurations)
        if item_id is not None:
            pulumi.set(__self__, "item_id", item_id)
        if quantity is not None:
            pulumi.set(__self__, "quantity", quantity)

    @property
    @pulumi.getter
    def duration(self) -> builtins.str:
        """
        Duration selected for the purchase of the product (defaults to "P1Y")
        """
        return pulumi.get(self, "duration")

    @property
    @pulumi.getter(name="planCode")
    def plan_code(self) -> builtins.str:
        """
        Identifier of the option offer
        """
        return pulumi.get(self, "plan_code")

    @property
    @pulumi.getter(name="pricingMode")
    def pricing_mode(self) -> builtins.str:
        """
        Pricing mode selected for the purchase of the product
        """
        return pulumi.get(self, "pricing_mode")

    @property
    @pulumi.getter
    def configurations(self) -> Optional[Sequence['outputs.NamePlanConfiguration']]:
        return pulumi.get(self, "configurations")

    @property
    @pulumi.getter(name="itemId")
    def item_id(self) -> Optional[builtins.float]:
        """
        Cart item to be linked
        """
        return pulumi.get(self, "item_id")

    @property
    @pulumi.getter
    def quantity(self) -> Optional[builtins.float]:
        """
        Quantity of product desired
        """
        return pulumi.get(self, "quantity")


@pulumi.output_type
class NamePlanConfiguration(dict):
    def __init__(__self__, *,
                 label: builtins.str,
                 value: builtins.str):
        """
        :param builtins.str label: Label for your configuration item
        :param builtins.str value: Value or resource URL on API.OVH.COM of your configuration item
        """
        pulumi.set(__self__, "label", label)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def label(self) -> builtins.str:
        """
        Label for your configuration item
        """
        return pulumi.get(self, "label")

    @property
    @pulumi.getter
    def value(self) -> builtins.str:
        """
        Value or resource URL on API.OVH.COM of your configuration item
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class NamePlanOption(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "planCode":
            suggest = "plan_code"
        elif key == "pricingMode":
            suggest = "pricing_mode"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in NamePlanOption. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        NamePlanOption.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        NamePlanOption.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 duration: builtins.str,
                 plan_code: builtins.str,
                 pricing_mode: builtins.str,
                 quantity: builtins.float,
                 configurations: Optional[Sequence['outputs.NamePlanOptionConfiguration']] = None):
        """
        :param builtins.str duration: Duration selected for the purchase of the product
        :param builtins.str plan_code: Identifier of the option offer
        :param builtins.str pricing_mode: Pricing mode selected for the purchase of the product
        :param builtins.float quantity: Quantity of product desired
        """
        pulumi.set(__self__, "duration", duration)
        pulumi.set(__self__, "plan_code", plan_code)
        pulumi.set(__self__, "pricing_mode", pricing_mode)
        pulumi.set(__self__, "quantity", quantity)
        if configurations is not None:
            pulumi.set(__self__, "configurations", configurations)

    @property
    @pulumi.getter
    def duration(self) -> builtins.str:
        """
        Duration selected for the purchase of the product
        """
        return pulumi.get(self, "duration")

    @property
    @pulumi.getter(name="planCode")
    def plan_code(self) -> builtins.str:
        """
        Identifier of the option offer
        """
        return pulumi.get(self, "plan_code")

    @property
    @pulumi.getter(name="pricingMode")
    def pricing_mode(self) -> builtins.str:
        """
        Pricing mode selected for the purchase of the product
        """
        return pulumi.get(self, "pricing_mode")

    @property
    @pulumi.getter
    def quantity(self) -> builtins.float:
        """
        Quantity of product desired
        """
        return pulumi.get(self, "quantity")

    @property
    @pulumi.getter
    def configurations(self) -> Optional[Sequence['outputs.NamePlanOptionConfiguration']]:
        return pulumi.get(self, "configurations")


@pulumi.output_type
class NamePlanOptionConfiguration(dict):
    def __init__(__self__, *,
                 label: builtins.str,
                 value: builtins.str):
        """
        :param builtins.str label: Label for your configuration item
        :param builtins.str value: Value or resource URL on API.OVH.COM of your configuration item
        """
        pulumi.set(__self__, "label", label)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def label(self) -> builtins.str:
        """
        Label for your configuration item
        """
        return pulumi.get(self, "label")

    @property
    @pulumi.getter
    def value(self) -> builtins.str:
        """
        Value or resource URL on API.OVH.COM of your configuration item
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class NameServersServer(dict):
    def __init__(__self__, *,
                 host: builtins.str,
                 ip: Optional[builtins.str] = None):
        """
        :param builtins.str host: The server hostname
        :param builtins.str ip: The server IP
        """
        pulumi.set(__self__, "host", host)
        if ip is not None:
            pulumi.set(__self__, "ip", ip)

    @property
    @pulumi.getter
    def host(self) -> builtins.str:
        """
        The server hostname
        """
        return pulumi.get(self, "host")

    @property
    @pulumi.getter
    def ip(self) -> Optional[builtins.str]:
        """
        The server IP
        """
        return pulumi.get(self, "ip")


@pulumi.output_type
class NameTargetSpec(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "dnsConfiguration":
            suggest = "dns_configuration"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in NameTargetSpec. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        NameTargetSpec.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        NameTargetSpec.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 dns_configuration: Optional['outputs.NameTargetSpecDnsConfiguration'] = None):
        """
        :param 'NameTargetSpecDnsConfigurationArgs' dns_configuration: The domain DNS configuration
        """
        if dns_configuration is not None:
            pulumi.set(__self__, "dns_configuration", dns_configuration)

    @property
    @pulumi.getter(name="dnsConfiguration")
    def dns_configuration(self) -> Optional['outputs.NameTargetSpecDnsConfiguration']:
        """
        The domain DNS configuration
        """
        return pulumi.get(self, "dns_configuration")


@pulumi.output_type
class NameTargetSpecDnsConfiguration(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "nameServers":
            suggest = "name_servers"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in NameTargetSpecDnsConfiguration. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        NameTargetSpecDnsConfiguration.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        NameTargetSpecDnsConfiguration.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 name_servers: Optional[Sequence['outputs.NameTargetSpecDnsConfigurationNameServer']] = None):
        """
        :param Sequence['NameTargetSpecDnsConfigurationNameServerArgs'] name_servers: The name servers to update
        """
        if name_servers is not None:
            pulumi.set(__self__, "name_servers", name_servers)

    @property
    @pulumi.getter(name="nameServers")
    def name_servers(self) -> Optional[Sequence['outputs.NameTargetSpecDnsConfigurationNameServer']]:
        """
        The name servers to update
        """
        return pulumi.get(self, "name_servers")


@pulumi.output_type
class NameTargetSpecDnsConfigurationNameServer(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "nameServer":
            suggest = "name_server"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in NameTargetSpecDnsConfigurationNameServer. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        NameTargetSpecDnsConfigurationNameServer.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        NameTargetSpecDnsConfigurationNameServer.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 ipv4: Optional[builtins.str] = None,
                 ipv6: Optional[builtins.str] = None,
                 name_server: Optional[builtins.str] = None):
        """
        :param builtins.str ipv4: The IPv4 associated to the name server
        :param builtins.str ipv6: The IPv6 associated to the name server
        :param builtins.str name_server: The host name
        """
        if ipv4 is not None:
            pulumi.set(__self__, "ipv4", ipv4)
        if ipv6 is not None:
            pulumi.set(__self__, "ipv6", ipv6)
        if name_server is not None:
            pulumi.set(__self__, "name_server", name_server)

    @property
    @pulumi.getter
    def ipv4(self) -> Optional[builtins.str]:
        """
        The IPv4 associated to the name server
        """
        return pulumi.get(self, "ipv4")

    @property
    @pulumi.getter
    def ipv6(self) -> Optional[builtins.str]:
        """
        The IPv6 associated to the name server
        """
        return pulumi.get(self, "ipv6")

    @property
    @pulumi.getter(name="nameServer")
    def name_server(self) -> Optional[builtins.str]:
        """
        The host name
        """
        return pulumi.get(self, "name_server")


@pulumi.output_type
class ZoneOrder(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "expirationDate":
            suggest = "expiration_date"
        elif key == "orderId":
            suggest = "order_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ZoneOrder. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ZoneOrder.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ZoneOrder.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 date: Optional[builtins.str] = None,
                 details: Optional[Sequence['outputs.ZoneOrderDetail']] = None,
                 expiration_date: Optional[builtins.str] = None,
                 order_id: Optional[builtins.int] = None):
        """
        :param builtins.str date: date
        :param Sequence['ZoneOrderDetailArgs'] details: Information about a Bill entry
        :param builtins.str expiration_date: expiration date
        :param builtins.int order_id: order id
        """
        if date is not None:
            pulumi.set(__self__, "date", date)
        if details is not None:
            pulumi.set(__self__, "details", details)
        if expiration_date is not None:
            pulumi.set(__self__, "expiration_date", expiration_date)
        if order_id is not None:
            pulumi.set(__self__, "order_id", order_id)

    @property
    @pulumi.getter
    def date(self) -> Optional[builtins.str]:
        """
        date
        """
        return pulumi.get(self, "date")

    @property
    @pulumi.getter
    def details(self) -> Optional[Sequence['outputs.ZoneOrderDetail']]:
        """
        Information about a Bill entry
        """
        return pulumi.get(self, "details")

    @property
    @pulumi.getter(name="expirationDate")
    def expiration_date(self) -> Optional[builtins.str]:
        """
        expiration date
        """
        return pulumi.get(self, "expiration_date")

    @property
    @pulumi.getter(name="orderId")
    def order_id(self) -> Optional[builtins.int]:
        """
        order id
        """
        return pulumi.get(self, "order_id")


@pulumi.output_type
class ZoneOrderDetail(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "orderDetailId":
            suggest = "order_detail_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ZoneOrderDetail. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ZoneOrderDetail.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ZoneOrderDetail.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 description: Optional[builtins.str] = None,
                 domain: Optional[builtins.str] = None,
                 order_detail_id: Optional[builtins.int] = None,
                 quantity: Optional[builtins.str] = None):
        """
        :param builtins.str description: description
        :param builtins.str domain: expiration date
        :param builtins.int order_detail_id: order detail id
        :param builtins.str quantity: quantity
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if domain is not None:
            pulumi.set(__self__, "domain", domain)
        if order_detail_id is not None:
            pulumi.set(__self__, "order_detail_id", order_detail_id)
        if quantity is not None:
            pulumi.set(__self__, "quantity", quantity)

    @property
    @pulumi.getter
    def description(self) -> Optional[builtins.str]:
        """
        description
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def domain(self) -> Optional[builtins.str]:
        """
        expiration date
        """
        return pulumi.get(self, "domain")

    @property
    @pulumi.getter(name="orderDetailId")
    def order_detail_id(self) -> Optional[builtins.int]:
        """
        order detail id
        """
        return pulumi.get(self, "order_detail_id")

    @property
    @pulumi.getter
    def quantity(self) -> Optional[builtins.str]:
        """
        quantity
        """
        return pulumi.get(self, "quantity")


@pulumi.output_type
class ZonePlan(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "planCode":
            suggest = "plan_code"
        elif key == "pricingMode":
            suggest = "pricing_mode"
        elif key == "catalogName":
            suggest = "catalog_name"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ZonePlan. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ZonePlan.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ZonePlan.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 duration: builtins.str,
                 plan_code: builtins.str,
                 pricing_mode: builtins.str,
                 catalog_name: Optional[builtins.str] = None,
                 configurations: Optional[Sequence['outputs.ZonePlanConfiguration']] = None):
        """
        :param builtins.str duration: duration
        :param builtins.str plan_code: Plan code
        :param builtins.str pricing_mode: Pricing model identifier
        :param builtins.str catalog_name: Catalog name
        :param Sequence['ZonePlanConfigurationArgs'] configurations: Representation of a configuration item for personalizing product. 2 configurations are required : one for `zone` and one for `template`
        """
        pulumi.set(__self__, "duration", duration)
        pulumi.set(__self__, "plan_code", plan_code)
        pulumi.set(__self__, "pricing_mode", pricing_mode)
        if catalog_name is not None:
            pulumi.set(__self__, "catalog_name", catalog_name)
        if configurations is not None:
            pulumi.set(__self__, "configurations", configurations)

    @property
    @pulumi.getter
    def duration(self) -> builtins.str:
        """
        duration
        """
        return pulumi.get(self, "duration")

    @property
    @pulumi.getter(name="planCode")
    def plan_code(self) -> builtins.str:
        """
        Plan code
        """
        return pulumi.get(self, "plan_code")

    @property
    @pulumi.getter(name="pricingMode")
    def pricing_mode(self) -> builtins.str:
        """
        Pricing model identifier
        """
        return pulumi.get(self, "pricing_mode")

    @property
    @pulumi.getter(name="catalogName")
    def catalog_name(self) -> Optional[builtins.str]:
        """
        Catalog name
        """
        return pulumi.get(self, "catalog_name")

    @property
    @pulumi.getter
    def configurations(self) -> Optional[Sequence['outputs.ZonePlanConfiguration']]:
        """
        Representation of a configuration item for personalizing product. 2 configurations are required : one for `zone` and one for `template`
        """
        return pulumi.get(self, "configurations")


@pulumi.output_type
class ZonePlanConfiguration(dict):
    def __init__(__self__, *,
                 label: builtins.str,
                 value: builtins.str):
        """
        :param builtins.str label: Identifier of the resource : `zone` or `template`
        :param builtins.str value: For `zone`, the value is the zone name `myzone.example.com`. For `template`, the value can be `basic`, `minimized` or `redirect` which is the same as `minimized` with additional entries for a redirect configuration.
        """
        pulumi.set(__self__, "label", label)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def label(self) -> builtins.str:
        """
        Identifier of the resource : `zone` or `template`
        """
        return pulumi.get(self, "label")

    @property
    @pulumi.getter
    def value(self) -> builtins.str:
        """
        For `zone`, the value is the zone name `myzone.example.com`. For `template`, the value can be `basic`, `minimized` or `redirect` which is the same as `minimized` with additional entries for a redirect configuration.
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class ZonePlanOption(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "planCode":
            suggest = "plan_code"
        elif key == "pricingMode":
            suggest = "pricing_mode"
        elif key == "catalogName":
            suggest = "catalog_name"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ZonePlanOption. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ZonePlanOption.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ZonePlanOption.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 duration: builtins.str,
                 plan_code: builtins.str,
                 pricing_mode: builtins.str,
                 catalog_name: Optional[builtins.str] = None,
                 configurations: Optional[Sequence['outputs.ZonePlanOptionConfiguration']] = None):
        """
        :param builtins.str duration: duration
        :param builtins.str plan_code: Plan code
        :param builtins.str pricing_mode: Pricing model identifier
        :param builtins.str catalog_name: Catalog name
        :param Sequence['ZonePlanOptionConfigurationArgs'] configurations: Representation of a configuration item for personalizing product
        """
        pulumi.set(__self__, "duration", duration)
        pulumi.set(__self__, "plan_code", plan_code)
        pulumi.set(__self__, "pricing_mode", pricing_mode)
        if catalog_name is not None:
            pulumi.set(__self__, "catalog_name", catalog_name)
        if configurations is not None:
            pulumi.set(__self__, "configurations", configurations)

    @property
    @pulumi.getter
    def duration(self) -> builtins.str:
        """
        duration
        """
        return pulumi.get(self, "duration")

    @property
    @pulumi.getter(name="planCode")
    def plan_code(self) -> builtins.str:
        """
        Plan code
        """
        return pulumi.get(self, "plan_code")

    @property
    @pulumi.getter(name="pricingMode")
    def pricing_mode(self) -> builtins.str:
        """
        Pricing model identifier
        """
        return pulumi.get(self, "pricing_mode")

    @property
    @pulumi.getter(name="catalogName")
    def catalog_name(self) -> Optional[builtins.str]:
        """
        Catalog name
        """
        return pulumi.get(self, "catalog_name")

    @property
    @pulumi.getter
    def configurations(self) -> Optional[Sequence['outputs.ZonePlanOptionConfiguration']]:
        """
        Representation of a configuration item for personalizing product
        """
        return pulumi.get(self, "configurations")


@pulumi.output_type
class ZonePlanOptionConfiguration(dict):
    def __init__(__self__, *,
                 label: builtins.str,
                 value: builtins.str):
        """
        :param builtins.str label: Identifier of the resource
        :param builtins.str value: Path to the resource in API.OVH.COM
        """
        pulumi.set(__self__, "label", label)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def label(self) -> builtins.str:
        """
        Identifier of the resource
        """
        return pulumi.get(self, "label")

    @property
    @pulumi.getter
    def value(self) -> builtins.str:
        """
        Path to the resource in API.OVH.COM
        """
        return pulumi.get(self, "value")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetPaymentmeanBankAccountResult',
    'AwaitableGetPaymentmeanBankAccountResult',
    'get_paymentmean_bank_account',
    'get_paymentmean_bank_account_output',
]

@pulumi.output_type
class GetPaymentmeanBankAccountResult:
    """
    A collection of values returned by getPaymentmeanBankAccount.
    """
    def __init__(__self__, default=None, description=None, description_regexp=None, id=None, state=None, use_default=None, use_oldest=None):
        if default and not isinstance(default, bool):
            raise TypeError("Expected argument 'default' to be a bool")
        pulumi.set(__self__, "default", default)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if description_regexp and not isinstance(description_regexp, str):
            raise TypeError("Expected argument 'description_regexp' to be a str")
        pulumi.set(__self__, "description_regexp", description_regexp)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if use_default and not isinstance(use_default, bool):
            raise TypeError("Expected argument 'use_default' to be a bool")
        pulumi.set(__self__, "use_default", use_default)
        if use_oldest and not isinstance(use_oldest, bool):
            raise TypeError("Expected argument 'use_oldest' to be a bool")
        pulumi.set(__self__, "use_oldest", use_oldest)

    @property
    @pulumi.getter
    def default(self) -> builtins.bool:
        """
        a boolean which tells if the retrieved bank account is marked as the default payment mean
        """
        return pulumi.get(self, "default")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        the description attribute of the bank account
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="descriptionRegexp")
    def description_regexp(self) -> Optional[builtins.str]:
        return pulumi.get(self, "description_regexp")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def state(self) -> builtins.str:
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="useDefault")
    def use_default(self) -> Optional[builtins.bool]:
        return pulumi.get(self, "use_default")

    @property
    @pulumi.getter(name="useOldest")
    def use_oldest(self) -> Optional[builtins.bool]:
        return pulumi.get(self, "use_oldest")


class AwaitableGetPaymentmeanBankAccountResult(GetPaymentmeanBankAccountResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPaymentmeanBankAccountResult(
            default=self.default,
            description=self.description,
            description_regexp=self.description_regexp,
            id=self.id,
            state=self.state,
            use_default=self.use_default,
            use_oldest=self.use_oldest)


def get_paymentmean_bank_account(description_regexp: Optional[builtins.str] = None,
                                 state: Optional[builtins.str] = None,
                                 use_default: Optional[builtins.bool] = None,
                                 use_oldest: Optional[builtins.bool] = None,
                                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetPaymentmeanBankAccountResult:
    """
    Use this data source to retrieve information about a bank account payment mean associated with an OVHcloud account.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    ba = ovh.Me.get_paymentmean_bank_account(use_default=True)
    ```


    :param builtins.str description_regexp: a regexp used to filter bank accounts on their `description` attributes.
    :param builtins.str state: Filter bank accounts on their `state` attribute. Can be "blockedForIncidents", "valid", "pendingValidation"
    :param builtins.bool use_default: Retrieve bank account marked as default payment mean.
    :param builtins.bool use_oldest: Retrieve oldest bank account. project.
    """
    __args__ = dict()
    __args__['descriptionRegexp'] = description_regexp
    __args__['state'] = state
    __args__['useDefault'] = use_default
    __args__['useOldest'] = use_oldest
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:Me/getPaymentmeanBankAccount:getPaymentmeanBankAccount', __args__, opts=opts, typ=GetPaymentmeanBankAccountResult).value

    return AwaitableGetPaymentmeanBankAccountResult(
        default=pulumi.get(__ret__, 'default'),
        description=pulumi.get(__ret__, 'description'),
        description_regexp=pulumi.get(__ret__, 'description_regexp'),
        id=pulumi.get(__ret__, 'id'),
        state=pulumi.get(__ret__, 'state'),
        use_default=pulumi.get(__ret__, 'use_default'),
        use_oldest=pulumi.get(__ret__, 'use_oldest'))
def get_paymentmean_bank_account_output(description_regexp: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                        state: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                        use_default: Optional[pulumi.Input[Optional[builtins.bool]]] = None,
                                        use_oldest: Optional[pulumi.Input[Optional[builtins.bool]]] = None,
                                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetPaymentmeanBankAccountResult]:
    """
    Use this data source to retrieve information about a bank account payment mean associated with an OVHcloud account.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    ba = ovh.Me.get_paymentmean_bank_account(use_default=True)
    ```


    :param builtins.str description_regexp: a regexp used to filter bank accounts on their `description` attributes.
    :param builtins.str state: Filter bank accounts on their `state` attribute. Can be "blockedForIncidents", "valid", "pendingValidation"
    :param builtins.bool use_default: Retrieve bank account marked as default payment mean.
    :param builtins.bool use_oldest: Retrieve oldest bank account. project.
    """
    __args__ = dict()
    __args__['descriptionRegexp'] = description_regexp
    __args__['state'] = state
    __args__['useDefault'] = use_default
    __args__['useOldest'] = use_oldest
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:Me/getPaymentmeanBankAccount:getPaymentmeanBankAccount', __args__, opts=opts, typ=GetPaymentmeanBankAccountResult)
    return __ret__.apply(lambda __response__: GetPaymentmeanBankAccountResult(
        default=pulumi.get(__response__, 'default'),
        description=pulumi.get(__response__, 'description'),
        description_regexp=pulumi.get(__response__, 'description_regexp'),
        id=pulumi.get(__response__, 'id'),
        state=pulumi.get(__response__, 'state'),
        use_default=pulumi.get(__response__, 'use_default'),
        use_oldest=pulumi.get(__response__, 'use_oldest')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['SavingsPlanArgs', 'SavingsPlan']

@pulumi.input_type
class SavingsPlanArgs:
    def __init__(__self__, *,
                 display_name: pulumi.Input[builtins.str],
                 flavor: pulumi.Input[builtins.str],
                 period: pulumi.Input[builtins.str],
                 service_name: pulumi.Input[builtins.str],
                 size: pulumi.Input[builtins.int],
                 auto_renewal: Optional[pulumi.Input[builtins.bool]] = None):
        """
        The set of arguments for constructing a SavingsPlan resource.
        :param pulumi.Input[builtins.str] display_name: Custom display name, used in invoices
        :param pulumi.Input[builtins.str] flavor: Savings Plan flavor. The list of available flavors can be retrieved in the next section.
        :param pulumi.Input[builtins.str] period: Periodicity of the Savings Plan
        :param pulumi.Input[builtins.str] service_name: ID of the public cloud project
        :param pulumi.Input[builtins.int] size: Size of the Savings Plan
        :param pulumi.Input[builtins.bool] auto_renewal: Whether Savings Plan should be renewed at the end of the period (defaults to false)
        """
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "flavor", flavor)
        pulumi.set(__self__, "period", period)
        pulumi.set(__self__, "service_name", service_name)
        pulumi.set(__self__, "size", size)
        if auto_renewal is not None:
            pulumi.set(__self__, "auto_renewal", auto_renewal)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Input[builtins.str]:
        """
        Custom display name, used in invoices
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter
    def flavor(self) -> pulumi.Input[builtins.str]:
        """
        Savings Plan flavor. The list of available flavors can be retrieved in the next section.
        """
        return pulumi.get(self, "flavor")

    @flavor.setter
    def flavor(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "flavor", value)

    @property
    @pulumi.getter
    def period(self) -> pulumi.Input[builtins.str]:
        """
        Periodicity of the Savings Plan
        """
        return pulumi.get(self, "period")

    @period.setter
    def period(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "period", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Input[builtins.str]:
        """
        ID of the public cloud project
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter
    def size(self) -> pulumi.Input[builtins.int]:
        """
        Size of the Savings Plan
        """
        return pulumi.get(self, "size")

    @size.setter
    def size(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "size", value)

    @property
    @pulumi.getter(name="autoRenewal")
    def auto_renewal(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether Savings Plan should be renewed at the end of the period (defaults to false)
        """
        return pulumi.get(self, "auto_renewal")

    @auto_renewal.setter
    def auto_renewal(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "auto_renewal", value)


@pulumi.input_type
class _SavingsPlanState:
    def __init__(__self__, *,
                 auto_renewal: Optional[pulumi.Input[builtins.bool]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 end_date: Optional[pulumi.Input[builtins.str]] = None,
                 flavor: Optional[pulumi.Input[builtins.str]] = None,
                 period: Optional[pulumi.Input[builtins.str]] = None,
                 period_end_action: Optional[pulumi.Input[builtins.str]] = None,
                 period_end_date: Optional[pulumi.Input[builtins.str]] = None,
                 period_start_date: Optional[pulumi.Input[builtins.str]] = None,
                 service_id: Optional[pulumi.Input[builtins.int]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 size: Optional[pulumi.Input[builtins.int]] = None,
                 start_date: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering SavingsPlan resources.
        :param pulumi.Input[builtins.bool] auto_renewal: Whether Savings Plan should be renewed at the end of the period (defaults to false)
        :param pulumi.Input[builtins.str] display_name: Custom display name, used in invoices
        :param pulumi.Input[builtins.str] end_date: End date of the Savings Plan
        :param pulumi.Input[builtins.str] flavor: Savings Plan flavor. The list of available flavors can be retrieved in the next section.
        :param pulumi.Input[builtins.str] period: Periodicity of the Savings Plan
        :param pulumi.Input[builtins.str] period_end_action: Action performed when reaching the end of the period (controles by the `auto_renewal` parameter)
        :param pulumi.Input[builtins.str] period_end_date: End date of the current period
        :param pulumi.Input[builtins.str] period_start_date: Start date of the current period
        :param pulumi.Input[builtins.int] service_id: Billing ID of the service
        :param pulumi.Input[builtins.str] service_name: ID of the public cloud project
        :param pulumi.Input[builtins.int] size: Size of the Savings Plan
        :param pulumi.Input[builtins.str] start_date: Start date of the Savings Plan
        :param pulumi.Input[builtins.str] status: Status of the Savings Plan
        """
        if auto_renewal is not None:
            pulumi.set(__self__, "auto_renewal", auto_renewal)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if end_date is not None:
            pulumi.set(__self__, "end_date", end_date)
        if flavor is not None:
            pulumi.set(__self__, "flavor", flavor)
        if period is not None:
            pulumi.set(__self__, "period", period)
        if period_end_action is not None:
            pulumi.set(__self__, "period_end_action", period_end_action)
        if period_end_date is not None:
            pulumi.set(__self__, "period_end_date", period_end_date)
        if period_start_date is not None:
            pulumi.set(__self__, "period_start_date", period_start_date)
        if service_id is not None:
            pulumi.set(__self__, "service_id", service_id)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if size is not None:
            pulumi.set(__self__, "size", size)
        if start_date is not None:
            pulumi.set(__self__, "start_date", start_date)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="autoRenewal")
    def auto_renewal(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether Savings Plan should be renewed at the end of the period (defaults to false)
        """
        return pulumi.get(self, "auto_renewal")

    @auto_renewal.setter
    def auto_renewal(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "auto_renewal", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Custom display name, used in invoices
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="endDate")
    def end_date(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        End date of the Savings Plan
        """
        return pulumi.get(self, "end_date")

    @end_date.setter
    def end_date(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "end_date", value)

    @property
    @pulumi.getter
    def flavor(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Savings Plan flavor. The list of available flavors can be retrieved in the next section.
        """
        return pulumi.get(self, "flavor")

    @flavor.setter
    def flavor(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "flavor", value)

    @property
    @pulumi.getter
    def period(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Periodicity of the Savings Plan
        """
        return pulumi.get(self, "period")

    @period.setter
    def period(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "period", value)

    @property
    @pulumi.getter(name="periodEndAction")
    def period_end_action(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Action performed when reaching the end of the period (controles by the `auto_renewal` parameter)
        """
        return pulumi.get(self, "period_end_action")

    @period_end_action.setter
    def period_end_action(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "period_end_action", value)

    @property
    @pulumi.getter(name="periodEndDate")
    def period_end_date(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        End date of the current period
        """
        return pulumi.get(self, "period_end_date")

    @period_end_date.setter
    def period_end_date(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "period_end_date", value)

    @property
    @pulumi.getter(name="periodStartDate")
    def period_start_date(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Start date of the current period
        """
        return pulumi.get(self, "period_start_date")

    @period_start_date.setter
    def period_start_date(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "period_start_date", value)

    @property
    @pulumi.getter(name="serviceId")
    def service_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Billing ID of the service
        """
        return pulumi.get(self, "service_id")

    @service_id.setter
    def service_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "service_id", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        ID of the public cloud project
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter
    def size(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Size of the Savings Plan
        """
        return pulumi.get(self, "size")

    @size.setter
    def size(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "size", value)

    @property
    @pulumi.getter(name="startDate")
    def start_date(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Start date of the Savings Plan
        """
        return pulumi.get(self, "start_date")

    @start_date.setter
    def start_date(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "start_date", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Status of the Savings Plan
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)


class SavingsPlan(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auto_renewal: Optional[pulumi.Input[builtins.bool]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 flavor: Optional[pulumi.Input[builtins.str]] = None,
                 period: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 size: Optional[pulumi.Input[builtins.int]] = None,
                 __props__=None):
        """
        Create and manage an OVHcloud Savings Plan

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        plan = ovh.savings_plan.SavingsPlan("plan",
            service_name="<public cloud project ID>",
            flavor="Rancher",
            period="P1M",
            size=2,
            display_name="one_month_rancher_savings_plan",
            auto_renewal=True)
        ```

        ## Import

        A savings plan can be imported using the following format: `service_name` and `id` of the savings plan, separated by "/" e.g.

        bash

        ```sh
        $ pulumi import ovh:SavingsPlan/savingsPlan:SavingsPlan plan service_name/savings_plan_id
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] auto_renewal: Whether Savings Plan should be renewed at the end of the period (defaults to false)
        :param pulumi.Input[builtins.str] display_name: Custom display name, used in invoices
        :param pulumi.Input[builtins.str] flavor: Savings Plan flavor. The list of available flavors can be retrieved in the next section.
        :param pulumi.Input[builtins.str] period: Periodicity of the Savings Plan
        :param pulumi.Input[builtins.str] service_name: ID of the public cloud project
        :param pulumi.Input[builtins.int] size: Size of the Savings Plan
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SavingsPlanArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create and manage an OVHcloud Savings Plan

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        plan = ovh.savings_plan.SavingsPlan("plan",
            service_name="<public cloud project ID>",
            flavor="Rancher",
            period="P1M",
            size=2,
            display_name="one_month_rancher_savings_plan",
            auto_renewal=True)
        ```

        ## Import

        A savings plan can be imported using the following format: `service_name` and `id` of the savings plan, separated by "/" e.g.

        bash

        ```sh
        $ pulumi import ovh:SavingsPlan/savingsPlan:SavingsPlan plan service_name/savings_plan_id
        ```

        :param str resource_name: The name of the resource.
        :param SavingsPlanArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SavingsPlanArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auto_renewal: Optional[pulumi.Input[builtins.bool]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 flavor: Optional[pulumi.Input[builtins.str]] = None,
                 period: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 size: Optional[pulumi.Input[builtins.int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SavingsPlanArgs.__new__(SavingsPlanArgs)

            __props__.__dict__["auto_renewal"] = auto_renewal
            if display_name is None and not opts.urn:
                raise TypeError("Missing required property 'display_name'")
            __props__.__dict__["display_name"] = display_name
            if flavor is None and not opts.urn:
                raise TypeError("Missing required property 'flavor'")
            __props__.__dict__["flavor"] = flavor
            if period is None and not opts.urn:
                raise TypeError("Missing required property 'period'")
            __props__.__dict__["period"] = period
            if service_name is None and not opts.urn:
                raise TypeError("Missing required property 'service_name'")
            __props__.__dict__["service_name"] = service_name
            if size is None and not opts.urn:
                raise TypeError("Missing required property 'size'")
            __props__.__dict__["size"] = size
            __props__.__dict__["end_date"] = None
            __props__.__dict__["period_end_action"] = None
            __props__.__dict__["period_end_date"] = None
            __props__.__dict__["period_start_date"] = None
            __props__.__dict__["service_id"] = None
            __props__.__dict__["start_date"] = None
            __props__.__dict__["status"] = None
        super(SavingsPlan, __self__).__init__(
            'ovh:SavingsPlan/savingsPlan:SavingsPlan',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            auto_renewal: Optional[pulumi.Input[builtins.bool]] = None,
            display_name: Optional[pulumi.Input[builtins.str]] = None,
            end_date: Optional[pulumi.Input[builtins.str]] = None,
            flavor: Optional[pulumi.Input[builtins.str]] = None,
            period: Optional[pulumi.Input[builtins.str]] = None,
            period_end_action: Optional[pulumi.Input[builtins.str]] = None,
            period_end_date: Optional[pulumi.Input[builtins.str]] = None,
            period_start_date: Optional[pulumi.Input[builtins.str]] = None,
            service_id: Optional[pulumi.Input[builtins.int]] = None,
            service_name: Optional[pulumi.Input[builtins.str]] = None,
            size: Optional[pulumi.Input[builtins.int]] = None,
            start_date: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None) -> 'SavingsPlan':
        """
        Get an existing SavingsPlan resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] auto_renewal: Whether Savings Plan should be renewed at the end of the period (defaults to false)
        :param pulumi.Input[builtins.str] display_name: Custom display name, used in invoices
        :param pulumi.Input[builtins.str] end_date: End date of the Savings Plan
        :param pulumi.Input[builtins.str] flavor: Savings Plan flavor. The list of available flavors can be retrieved in the next section.
        :param pulumi.Input[builtins.str] period: Periodicity of the Savings Plan
        :param pulumi.Input[builtins.str] period_end_action: Action performed when reaching the end of the period (controles by the `auto_renewal` parameter)
        :param pulumi.Input[builtins.str] period_end_date: End date of the current period
        :param pulumi.Input[builtins.str] period_start_date: Start date of the current period
        :param pulumi.Input[builtins.int] service_id: Billing ID of the service
        :param pulumi.Input[builtins.str] service_name: ID of the public cloud project
        :param pulumi.Input[builtins.int] size: Size of the Savings Plan
        :param pulumi.Input[builtins.str] start_date: Start date of the Savings Plan
        :param pulumi.Input[builtins.str] status: Status of the Savings Plan
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SavingsPlanState.__new__(_SavingsPlanState)

        __props__.__dict__["auto_renewal"] = auto_renewal
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["end_date"] = end_date
        __props__.__dict__["flavor"] = flavor
        __props__.__dict__["period"] = period
        __props__.__dict__["period_end_action"] = period_end_action
        __props__.__dict__["period_end_date"] = period_end_date
        __props__.__dict__["period_start_date"] = period_start_date
        __props__.__dict__["service_id"] = service_id
        __props__.__dict__["service_name"] = service_name
        __props__.__dict__["size"] = size
        __props__.__dict__["start_date"] = start_date
        __props__.__dict__["status"] = status
        return SavingsPlan(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="autoRenewal")
    def auto_renewal(self) -> pulumi.Output[builtins.bool]:
        """
        Whether Savings Plan should be renewed at the end of the period (defaults to false)
        """
        return pulumi.get(self, "auto_renewal")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[builtins.str]:
        """
        Custom display name, used in invoices
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="endDate")
    def end_date(self) -> pulumi.Output[builtins.str]:
        """
        End date of the Savings Plan
        """
        return pulumi.get(self, "end_date")

    @property
    @pulumi.getter
    def flavor(self) -> pulumi.Output[builtins.str]:
        """
        Savings Plan flavor. The list of available flavors can be retrieved in the next section.
        """
        return pulumi.get(self, "flavor")

    @property
    @pulumi.getter
    def period(self) -> pulumi.Output[builtins.str]:
        """
        Periodicity of the Savings Plan
        """
        return pulumi.get(self, "period")

    @property
    @pulumi.getter(name="periodEndAction")
    def period_end_action(self) -> pulumi.Output[builtins.str]:
        """
        Action performed when reaching the end of the period (controles by the `auto_renewal` parameter)
        """
        return pulumi.get(self, "period_end_action")

    @property
    @pulumi.getter(name="periodEndDate")
    def period_end_date(self) -> pulumi.Output[builtins.str]:
        """
        End date of the current period
        """
        return pulumi.get(self, "period_end_date")

    @property
    @pulumi.getter(name="periodStartDate")
    def period_start_date(self) -> pulumi.Output[builtins.str]:
        """
        Start date of the current period
        """
        return pulumi.get(self, "period_start_date")

    @property
    @pulumi.getter(name="serviceId")
    def service_id(self) -> pulumi.Output[builtins.int]:
        """
        Billing ID of the service
        """
        return pulumi.get(self, "service_id")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[builtins.str]:
        """
        ID of the public cloud project
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter
    def size(self) -> pulumi.Output[builtins.int]:
        """
        Size of the Savings Plan
        """
        return pulumi.get(self, "size")

    @property
    @pulumi.getter(name="startDate")
    def start_date(self) -> pulumi.Output[builtins.str]:
        """
        Start date of the Savings Plan
        """
        return pulumi.get(self, "start_date")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        Status of the Savings Plan
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetLogsInputEngineResult',
    'AwaitableGetLogsInputEngineResult',
    'get_logs_input_engine',
    'get_logs_input_engine_output',
]

@pulumi.output_type
class GetLogsInputEngineResult:
    """
    A collection of values returned by getLogsInputEngine.
    """
    def __init__(__self__, id=None, is_deprecated=None, name=None, service_name=None, version=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if is_deprecated and not isinstance(is_deprecated, bool):
            raise TypeError("Expected argument 'is_deprecated' to be a bool")
        pulumi.set(__self__, "is_deprecated", is_deprecated)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)
        if version and not isinstance(version, str):
            raise TypeError("Expected argument 'version' to be a str")
        pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isDeprecated")
    def is_deprecated(self) -> builtins.bool:
        return pulumi.get(self, "is_deprecated")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> builtins.str:
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter
    def version(self) -> builtins.str:
        return pulumi.get(self, "version")


class AwaitableGetLogsInputEngineResult(GetLogsInputEngineResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetLogsInputEngineResult(
            id=self.id,
            is_deprecated=self.is_deprecated,
            name=self.name,
            service_name=self.service_name,
            version=self.version)


def get_logs_input_engine(is_deprecated: Optional[builtins.bool] = None,
                          name: Optional[builtins.str] = None,
                          service_name: Optional[builtins.str] = None,
                          version: Optional[builtins.str] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetLogsInputEngineResult:
    """
    Use this data source to retrieve information about a DBaas logs input engine.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    logstash = ovh.Dbaas.get_logs_input_engine(service_name="ldp-xx-xxxxx",
        name="logstash",
        version="6.8",
        is_deprecated=True)
    ```


    :param builtins.bool is_deprecated: Indicates if engine will soon not be supported.
    :param builtins.str name: The name of the logs input engine.
    :param builtins.str service_name: The service name. It's the ID of your Logs Data Platform instance.
    :param builtins.str version: Software version
    """
    __args__ = dict()
    __args__['isDeprecated'] = is_deprecated
    __args__['name'] = name
    __args__['serviceName'] = service_name
    __args__['version'] = version
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:Dbaas/getLogsInputEngine:getLogsInputEngine', __args__, opts=opts, typ=GetLogsInputEngineResult).value

    return AwaitableGetLogsInputEngineResult(
        id=pulumi.get(__ret__, 'id'),
        is_deprecated=pulumi.get(__ret__, 'is_deprecated'),
        name=pulumi.get(__ret__, 'name'),
        service_name=pulumi.get(__ret__, 'service_name'),
        version=pulumi.get(__ret__, 'version'))
def get_logs_input_engine_output(is_deprecated: Optional[pulumi.Input[Optional[builtins.bool]]] = None,
                                 name: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                                 version: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                 opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetLogsInputEngineResult]:
    """
    Use this data source to retrieve information about a DBaas logs input engine.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    logstash = ovh.Dbaas.get_logs_input_engine(service_name="ldp-xx-xxxxx",
        name="logstash",
        version="6.8",
        is_deprecated=True)
    ```


    :param builtins.bool is_deprecated: Indicates if engine will soon not be supported.
    :param builtins.str name: The name of the logs input engine.
    :param builtins.str service_name: The service name. It's the ID of your Logs Data Platform instance.
    :param builtins.str version: Software version
    """
    __args__ = dict()
    __args__['isDeprecated'] = is_deprecated
    __args__['name'] = name
    __args__['serviceName'] = service_name
    __args__['version'] = version
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:Dbaas/getLogsInputEngine:getLogsInputEngine', __args__, opts=opts, typ=GetLogsInputEngineResult)
    return __ret__.apply(lambda __response__: GetLogsInputEngineResult(
        id=pulumi.get(__response__, 'id'),
        is_deprecated=pulumi.get(__response__, 'is_deprecated'),
        name=pulumi.get(__response__, 'name'),
        service_name=pulumi.get(__response__, 'service_name'),
        version=pulumi.get(__response__, 'version')))
